<?php
// Iniciar la sesión
session_start();

// Incluir la conexión a la base de datos
include 'conexion.php';

// Verificar si el usuario está logueado
if (!isset($_SESSION['correo'])) {
    header("Location: login.php?error=Inicia sesión para acceder a esta página");
    exit();
}

// Cerrar la conexión
$conn = null;
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Página Principal - Quiztudio</title>
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Roboto:wght@400;700&family=Poppins:wght@600&display=swap">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0/css/all.min.css">
    <style>
        /* Estilos generales */
        body, html {
            margin: 0;
            padding: 0;
            height: 100%;
            font-family: 'Roboto', sans-serif;
            background-color: rgb(130, 165, 235);
            background-image: linear-gradient(135deg, rgba(63, 94, 251, 0.8) 0%, rgba(252, 70, 107, 0.8) 100%);
            overflow-x: hidden;
        }

        /* Contenedor principal */
        .main-container {
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }

        /* Barra de navegación */
        .navbar {
            background-color: rgba(0, 0, 0, 0.2);
            padding: 15px 30px;
            display: flex;
            justify-content: space-between;
            align-items: center;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
        }

        .logo {
            display: flex;
            align-items: center;
            gap: 10px;
            font-size: 1.8rem;
            font-weight: bold;
            color: white;
            text-decoration: none;
        }

        .nav-links {
            display: flex;
            gap: 20px;
            align-items: center;
        }

        .nav-link {
            color: white;
            text-decoration: none;
            font-weight: 500;
            padding: 8px 15px;
            border-radius: 50px;
            transition: all 0.3s ease;
            background-color: rgb(248, 104, 20);
            border: 2px solid white;
        }

        .nav-link:hover {
            background-color: white;
            color: rgb(248, 104, 20);
            transform: scale(1.05);
        }

        .social-icon {
            color: white;
            background-color: rgb(248, 104, 20);
            border: 2px solid white;
            border-radius: 50%;
            width: 35px;
            height: 35px;
            display: flex;
            justify-content: center;
            align-items: center;
            font-size: 1rem;
            transition: all 0.3s ease;
        }

        .social-icon:hover {
            background-color: white;
            color: rgb(248, 104, 20);
            transform: scale(1.1);
        }

        /* Contenido central */
        .content {
            flex: 1;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            padding: 40px 20px;
            position: relative;
            z-index: 1;
        }

        /* Patrones decorativos */
        .bg-pattern {
            position: absolute;
            width: 100%;
            height: 100%;
            background-image: 
                radial-gradient(circle at 20% 30%, rgba(255, 255, 255, 0.2) 0%, transparent 10%),
                radial-gradient(circle at 80% 70%, rgba(255, 255, 255, 0.2) 0%, transparent 10%),
                radial-gradient(circle at 40% 80%, rgba(255, 255, 255, 0.2) 0%, transparent 8%),
                radial-gradient(circle at 60% 20%, rgba(255, 255, 255, 0.2) 0%, transparent 8%);
            z-index: -1;
        }

        /* Elementos flotantes decorativos */
        .floating-shapes {
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            z-index: -1;
            overflow: hidden;
        }

        .shape {
            position: absolute;
            background-color: rgba(255, 255, 255, 0.1);
            border-radius: 50%;
            animation: float 15s infinite ease-in-out;
        }

        .shape:nth-child(1) {
            width: 100px;
            height: 100px;
            top: 10%;
            left: 10%;
            animation-delay: 0s;
        }

        .shape:nth-child(2) {
            width: 150px;
            height: 150px;
            top: 70%;
            left: 80%;
            animation-delay: 1s;
        }

        .shape:nth-child(3) {
            width: 60px;
            height: 60px;
            top: 30%;
            left: 85%;
            animation-delay: 2s;
        }

        .shape:nth-child(4) {
            width: 80px;
            height: 80px;
            top: 80%;
            left: 20%;
            animation-delay: 3s;
        }

        .shape:nth-child(5) {
            width: 120px;
            height: 120px;
            top: 40%;
            left: 40%;
            animation-delay: 4s;
        }

        @keyframes float {
            0%, 100% {
                transform: translateY(0) translateX(0);
            }
            25% {
                transform: translateY(-20px) translateX(10px);
            }
            50% {
                transform: translateY(0) translateX(20px);
            }
            75% {
                transform: translateY(20px) translateX(10px);
            }
        }

        /* Título principal */
        .main-title {
            font-family: 'Poppins', sans-serif;
            font-size: 4rem;
            font-weight: bold;
            color: #fff;
            text-shadow: 0 2px 10px rgba(0, 0, 0, 0.3), 0 0 40px rgba(255, 102, 0, 0.8);
            margin-bottom: 5px;
            text-align: center;
            animation: pulse 2s infinite;
        }

        @keyframes pulse {
            0%, 100% {
                transform: scale(1);
            }
            50% {
                transform: scale(1.05);
            }
        }

        /* Eslogan */
        .slogan {
            font-size: 1.4rem;
            font-weight: normal;
            color: white;
            text-shadow: 0 2px 5px rgba(0, 0, 0, 0.5);
            margin-bottom: 20px;
            text-align: center;
        }

        /* Contenedor principal */
        .content-wrapper {
            background: rgba(255, 255, 255, 0.15);
            backdrop-filter: blur(10px);
            border: 2px solid rgba(255, 255, 255, 0.3);
            border-radius: 20px;
            padding: 30px;
            width: 80%;
            max-width: 800px;
            box-shadow: 0 10px 30px rgba(0, 0, 0, 0.2);
            margin-bottom: 30px;
        }

        /* Mensaje de bienvenida */
        .welcome-message {
            font-size: 1.3rem;
            color: white;
            background-color: rgba(248, 104, 20, 0.8);
            padding: 15px;
            border-radius: 10px;
            text-align: center;
            margin-bottom: 30px;
            border: 2px solid white;
            font-weight: bold;
        }

        /* Contenedores de trivia */
        .trivia-container {
            background: rgba(255, 255, 255, 0.1);
            backdrop-filter: blur(5px);
            border: 2px solid rgba(255, 255, 255, 0.3);
            border-radius: 15px;
            padding: 20px;
            margin-bottom: 20px;
            display: flex;
            align-items: center;
            gap: 15px;
            cursor: pointer;
            transition: all 0.3s ease;
            width: 100%;
            box-sizing: border-box;
        }

        .trivia-container:hover {
            background: rgba(255, 255, 255, 0.2);
            transform: translateY(-5px);
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.2);
        }

        .trivia-container i {
            font-size: 2rem;
            color: white;
            min-width: 40px;
            text-align: center;
        }

        .trivia-container h2 {
            margin: 0;
            font-size: 1.5rem;
            color: white;
            flex-grow: 1;
            text-align: left;
        }

        /* Logo */
        .logo-container {
            margin-bottom: 30px;
            text-align: center;
        }

        .logo-container img {
            max-width: 250px;
            max-height: 250px;
            border-radius: 20px;
            border: 3px solid rgba(255, 255, 255, 0.5);
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.2);
        }

        /* Footer */
        .footer {
            background-color: rgba(0, 0, 0, 0.2);
            padding: 20px;
            text-align: center;
            color: white;
        }

        .footer p {
            margin: 0;
        }

        /* Responsivo */
        @media (max-width: 768px) {
            .main-title {
                font-size: 2.5rem;
            }
            
            .slogan {
                font-size: 1.1rem;
            }
            
            .content-wrapper {
                width: 95%;
                padding: 20px;
            }
            
            .nav-links {
                flex-direction: column;
                gap: 10px;
            }
            
            .trivia-container {
                flex-direction: column;
                text-align: center;
            }
            
            .trivia-container h2 {
                text-align: center;
            }
            
            .logo-container img {
                max-width: 200px;
            }
        }
    </style>
</head>
<body>
    <div class="main-container">
        <!-- Barra de navegación -->
        <nav class="navbar">
            <a href="index.php" class="logo">
                <i class="fas fa-brain"></i> Quiztudio
            </a>
            <div class="nav-links">
                <a href="https://unitecnica.app/" target="_blank" class="social-icon" aria-label="Visita Unitecnica App">
                    <i class="fas fa-graduation-cap"></i>
                </a>
                <a href="https://unitecnica.net/" target="_blank" class="social-icon" aria-label="Visita Unitecnica Net">
                    <i class="fas fa-university"></i>
                </a>
                <a href="index.php" class="nav-link">Inicio</a>
                <a href="RegistrarUsuario.php" class="nav-link">Registrar Usuario</a>
                <a href="cerrar_sesion.php" class="nav-link">Cerrar Sesión</a>
                <a href="https://www.facebook.com/profile.php?id=61574616325247" target="_blank" class="social-icon" aria-label="Facebook">
                    <i class="fab fa-facebook"></i>
                </a>
                <a href="https://www.instagram.com/quiztudio/" target="_blank" class="social-icon" aria-label="Instagram">
                    <i class="fab fa-instagram"></i>
                </a>
            </div>
        </nav>
        
        <!-- Contenido principal -->
        <div class="content">
            <!-- Fondo con patrones -->
            <div class="bg-pattern"></div>
            
            <!-- Formas flotantes -->
            <div class="floating-shapes">
                <div class="shape"></div>
                <div class="shape"></div>
                <div class="shape"></div>
                <div class="shape"></div>
                <div class="shape"></div>
            </div>
            
            <!-- Título principal -->
            <h1 class="main-title">💭 Quiztudio 🎓</h1>
            <p class="slogan">📚 Aprende jugando y diviértete aprendiendo 📝</p>  

            <!-- Contenedor principal -->
            <div class="content-wrapper">
                <div class="logo-container">
                    <img src="logo.JPG" alt="Logo de Quiztudio">
                </div>
                
                <div class="welcome-message">
                    🤓 Bienvenido a Quiztudio, selecciona una trivia 🤓
                </div>

                <div class="trivia-container" onclick="window.location.href='trivia_sistemas.php'">
                    <i class="fas fa-robot"></i>
                    <h2>Trivia Sistemas IA</h2>
                </div>

                <div class="trivia-container" onclick="window.location.href='trivia_diseno.php'">
                    <i class="fas fa-paint-brush"></i>
                    <h2>Trivia Diseño Gráfico Digital</h2>
                </div>

                <div class="trivia-container" onclick="window.location.href='trivia_animacion.php'">
                    <i class="fas fa-gamepad"></i>
                    <h2>Trivia Animación 3D y Videojuegos</h2>
                </div>
            </div>
        </div>
        
        <!-- Footer -->
        <footer class="footer">
            <p>© 2025 Quiztudio. Todos los derechos reservados.</p>
        </footer>
    </div>
</body>
</html>